==> worker-languagedetection-2.4.0-82-sources.jar: com/hpe/caf/worker/languagedetection/LanguageDetectionWorkerConfiguration.java <==
/*
 * Copyright 2015-2017 EntIT Software LLC, a Micro Focus company.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.hpe.caf.worker.languagedetection;

import com.hpe.caf.api.Configuration;
import javax.validation.constraints.NotNull;

/**
 * Language Detection Worker specific configuration.
 */
@Configuration
public class LanguageDetectionWorkerConfiguration {

    @NotNull
    private LanguageDetectionResultFormat resultFormat;

    /**
     * Getter for property 'resultFormat' which controls the format that langauge detection results are output.
     * @return value for property 'resultFormat'.
     */
    public LanguageDetectionResultFormat getResultFormat() {
        return resultFormat;
    }

    /**
     * Setter for property 'resultFormat' which controls the format that langauge detection results are output.
     * @param resultFormat value to set for property 'resultFormat'.
     */
    public void setResultFormat(final LanguageDetectionResultFormat resultFormat) {
        this.resultFormat = resultFormat;
    }
}

==> worker-languagedetection-3.2.0-608-sources.jar: com/hpe/caf/worker/languagedetection/LanguageDetectionWorkerConfiguration.java <==
/*
 * Copyright 2015-2020 Micro Focus or one of its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.hpe.caf.worker.languagedetection;

import com.hpe.caf.api.Configuration;
import javax.validation.constraints.NotNull;

/**
 * Language Detection Worker specific configuration.
 */
@Configuration
public class LanguageDetectionWorkerConfiguration
{
    @NotNull
    private LanguageDetectionResultFormat resultFormat;

    /**
     * Getter for property 'resultFormat' which controls the format that language detection results are output.
     *
     * @return value for property 'resultFormat'.
     */
    public LanguageDetectionResultFormat getResultFormat()
    {
        return resultFormat;
    }

    /**
     * Setter for property 'resultFormat' which controls the format that langauge detection results are output.
     *
     * @param resultFormat value to set for property 'resultFormat'.
     */
    public void setResultFormat(final LanguageDetectionResultFormat resultFormat)
    {
        this.resultFormat = resultFormat;
    }
}
